shinyUI(
  navbarPage( "Evaluate Cutpoints", theme = shinytheme("flatly"), fluid=TRUE,
  
    tabPanel( "Estimate",
      includeCSS( "styles.css" ),
      sidebarPanel(
        fileInput( 'datafile', 'Choose tab-delimited file',
          accept=c( 'text/csv', 'text/tab-separated-values,text/plain', ".txt")
        ),
    
        uiOutput( "chooseNrOfGroups" ),
        uiOutput( "selectedGroupIntructions" ),
        uiOutput( "divionBase" ),
        uiOutput( "tdivionBase" ),
        uiOutput( "selectedDivisionsIntructions" ),
        uiOutput( "outcomeDivisionsIntructions"),
        uiOutput( "fileInstructions" ),
    
        actionButton( "cutoff", "Find cutoff" )
      ),
      mainPanel(
        div( class="app-wrapper",
        
        conditionalPanel(
          condition = "input.showfile==true",
          tableOutput( "filetable" )
        ),
    
        conditionalPanel(
          condition = "input.divisonBase === 'outcome' && input.cutoffoutputMethod === 'youden'  && input.nrGroups == '2'",
            tagList(
              conditionalPanel( condition="$('html').hasClass('shiny-busy')",
                                    tags$div("Loading...",class="loader")),
              div( tableOutput( "youdenTable" ), align = "center" ),
              div( plotlyOutput( "youdenHist" ), width = "50em",  align = "center" ),
              div( plotOutput( "YoudenPlot", width = "40em", height = "40em" ), align = "center" ),
              div( verbatimTextOutput( "error" ), align = "center" )
            )
        ),
        
        conditionalPanel(
          condition = "input.divisonBase === 'outcome' && input.cutoffoutputMethod === 'roc' && input.nrGroups == '2'",
            tagList(
            conditionalPanel(condition="$('html').hasClass('shiny-busy')",
                                    tags$div("Loading...",class="loader")),
              div(tableOutput( "ROCTable" ), align = "center" ),
              div(plotlyOutput( "ROCHist" ), width = "50em", align = "center" ),
              div(plotOutput( "ROCPlot", width = "40em", height = "40em" ), align = "center" )
            )
        ),
    
        conditionalPanel(
          condition = "input.divisonBase === 'survival' && input.cutoffMethod === 'maxstat' && input.nrGroups == '2'",
            tagList(
              conditionalPanel(condition="$('html').hasClass('shiny-busy')",
                                    tags$div("Loading...",class="loader")),
              div( tableOutput( "survivalMaxstatTable" ), align = "center" ),
              div( tableOutput( "HRMaxstatTable" ), align = "center" ),
              div( plotlyOutput( "survivalMaxstatGraphResult" ), width = "50em", align = "center" ),
              div( plotlyOutput( "survivalMaxstatHist" ), width = "50em", align = "center"  ),
              div( plotlyOutput( "survivalMaxstatGraphSurv" ), width = "50em", align = "center" )
            )
        ),
    
        conditionalPanel(
          condition = "input.divisonBase === 'survival' && input.cutoffMethod === 'cutp' && input.nrGroups == '2'",
            tagList(
              conditionalPanel(condition="$('html').hasClass('shiny-busy')",
                  tags$div("Loading...",class="loader")),
              div( tableOutput( "survivalCutpTable" ), align = "center" ),
              div( tableOutput( "HRcutpTable" ), align = "center" ),
              div( plotlyOutput( "survivalcutpHist" ), width = "50em", align = "center" ),
              div( plotlyOutput( "survivalCutpGraphSurv" ),width = "50em", align = "center")
            )
        ),
    
        conditionalPanel(
          condition = "input.divisonBase === 'adapt' && input.nrGroups == '2'",
            tagList(
              conditionalPanel(condition="$('html').hasClass('shiny-busy')",
                                    tags$div("Loading...",class="loader")),
              div( plotlyOutput( "heatmap", width = "50em", height = "150px" ), align = "center" ),
              div( tableOutput( "adaptresultTable" ), align = "center" ),
              div( tableOutput( "adaptHRTable" ), align = "center" ),
              div( verbatimTextOutput( "click", placeholder = FALSE ), align = "center" ),
              div( uiOutput( "adaptSlider" ), align = "center" ),
              div( plotlyOutput( "adaptHist", height = "100%" ), width = "50em", align = "center" ),
              div( plotlyOutput( "adaptResult", height = "100%" ), width = "50em", align = "center" )
            )
        ),
    
        conditionalPanel(
          condition = "input.tdivisonBase === 'rolr' && input.nrGroups == '3'",
            tagList(
              conditionalPanel(condition="$('html').hasClass('shiny-busy')",
                                    tags$div("Loading...",class="loader")),
              div( tableOutput( "threeSplits" ), align = "center" ),
              div( tableOutput( "Check" ), align = "center" ),
              div( tableOutput( "lowCheck" ), align = "center" ),
              div( plotlyOutput( "rolrHist" ), width = "50em", align = "center" ),
              div( plotlyOutput( "threeGraph" ), width = "50em", align = "center" ),
              div( plotlyOutput( "lowmediumfit" ), width = "50em", align = "center" ),
              div( plotlyOutput( "lowhighfit" ), width = "50em", align = "center" ),
              div( plotlyOutput( "mediumhighfit" ), width = "50em", align = "center" )
            )
        ),
    
        conditionalPanel(
          condition = "input.tdivisonBase === 'adapt' && input.nrGroups == '3'",
            tagList(
              conditionalPanel(condition="$('html').hasClass('shiny-busy')",
                                    tags$div("Loading...",class="loader")),
              div( uiOutput( "tadaptSliderMin" ), align = "center" ),
              div( uiOutput( "tadaptSliderMax" ), align = "center" ),
              div( tableOutput( "threeadaptTable" ), align = "center" ),
              div( tableOutput( "Checkadapt" ), align = "center" ),
              div( tableOutput( "lowadaptCheck" ), align = "center" ),
              div( plotlyOutput( "tadaptHist" ), width = "50em", align = "center" ),
              div( plotlyOutput( "tadaptResult" ), width = "50em", align = "center" ),
              div( plotlyOutput( "lowmediumadapt" ), width = "50em", align = "center" ),
              div( plotlyOutput( "lowhighadapt" ), width = "50em", align = "center" ),
              div( plotlyOutput( "mediumhighadapt" ), width = "50em", align = "center" )
            )
          )
        )
      )
    )
  )
  )